=== modified file 'EventDetails.qml'
--- EventDetails.qml	2014-07-17 13:34:03 +0000
+++ EventDetails.qml	2014-07-23 18:17:21 +0000
@@ -307,6 +307,7 @@
                 }
                 Label{
                     id:calendarName
+                    objectName: "calendarName"
                     anchors.verticalCenter: parent.verticalCenter
                     color: headerColor
                 }

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2014-07-17 13:34:03 +0000
+++ NewEvent.qml	2014-07-23 18:17:21 +0000
@@ -463,6 +463,7 @@
 
                 OptionSelector{
                     id: calendarsOption
+                    objectName: "calendarsOption"
                     anchors.right: parent.right
                     width: parent.width - calendarLabel.width - units.gu(1)
                     containerHeight: itemHeight * 4

=== modified file 'tests/autopilot/calendar_app/data.py'
--- tests/autopilot/calendar_app/data.py	2014-06-27 00:03:24 +0000
+++ tests/autopilot/calendar_app/data.py	2014-07-23 18:17:21 +0000
@@ -36,10 +36,11 @@
 
     """Event data object for user acceptance tests."""
 
-    def __init__(self, name, description, location, guests):
+    def __init__(self, calendar, name, description, location, guests):
         # TODO add start date and end date, is all day event, recurrence and
         # reminders. --elopio - 2014-06-26
         super(Event, self).__init__()
+        self.calendar = calendar
         self.name = name
         self.description = description
         self.location = location
@@ -50,8 +51,9 @@
         """Return a unique event."""
         if unique_id is None:
             unique_id = str(uuid.uuid1())
+        calendar = 'Personal'
         name = 'Test event {}'.format(unique_id)
         description = 'Test description {}.'.format(unique_id)
         location = 'Test location {}'.format(unique_id)
         guests = ['Test guest {} 1'.format(unique_id)]
-        return cls(name, description, location, guests)
+        return cls(calendar, name, description, location, guests)

=== modified file 'tests/autopilot/calendar_app/emulators.py'
--- tests/autopilot/calendar_app/emulators.py	2014-07-22 23:43:11 +0000
+++ tests/autopilot/calendar_app/emulators.py	2014-07-23 18:17:21 +0000
@@ -417,12 +417,14 @@
         """Fill the add event form.
 
         :param event_information: Values of the event to fill the form.
-        :type event_information: data object with the attributes name,
-            description, location and guests.
+        :type event_information: data object with the attributes
+            calendar, name, description, location and guests.
 
         """
         # TODO fill start date and end date, is all day event, recurrence and
         # reminders. --elopio - 2014-06-26
+        if event_information.calendar is not None:
+            self._select_calendar(event_information.calendar)
         if event_information.name is not None:
             self._fill_name(event_information.name)
         if event_information.description is not None:
@@ -464,16 +466,24 @@
         self._ensure_entry_field_visible_and_write(
             'eventPeopleInput', value[0])
 
+    def _select_calendar(self, calendar):
+        self._get_calendar().select_option('Label', text=calendar)
+
+    def _get_calendar(self):
+        return self.select_single(ubuntuuitoolkit.OptionSelector,
+                                  objectName="calendarsOption")
+
     def _get_form_values(self):
         # TODO get start date and end date, is all day event, recurrence and
         # reminders. --elopio - 2014-06-26
+        calendar = self._get_calendar().get_current_label().text
         name = self._get_new_event_entry_field('newEventName').text
         description = self._get_description_text_area().text
         location = self._get_new_event_entry_field('eventLocationInput').text
         # TODO once bug http://pad.lv/1295941 is fixed, we will have to build
         # the list of guests. --elopio - 2014-06-26
         guests = [self._get_new_event_entry_field('eventPeopleInput').text]
-        return data.Event(name, description, location, guests)
+        return data.Event(calendar, name, description, location, guests)
 
     @autopilot.logging.log_action(logger.info)
     def _save(self):
@@ -510,11 +520,15 @@
 
     def get_event_information(self):
         """Return the information of the event."""
+        calendar = self._get_calendar()
         name = self._get_name()
         description = self._get_description()
         location = self._get_location()
         guests = self._get_guests()
-        return data.Event(name, description, location, guests)
+        return data.Event(calendar, name, description, location, guests)
+
+    def _get_calendar(self):
+        return self._get_label_text('calendarName')
 
     def _get_name(self):
         return self._get_label_text('titleLabel')

=== modified file 'tests/autopilot/calendar_app/tests/test_data.py'
--- tests/autopilot/calendar_app/tests/test_data.py	2014-06-27 00:03:24 +0000
+++ tests/autopilot/calendar_app/tests/test_data.py	2014-07-23 18:17:21 +0000
@@ -24,6 +24,7 @@
     def test_make_unique_event_must_return_event_with_unique_id(self):
         event = data.Event.make_unique(unique_id='test uuid')
 
+        self.assertEqual(event.calendar, 'Personal')
         self.assertEqual(event.name, 'Test event test uuid')
         self.assertEqual(event.description, 'Test description test uuid.')
         self.assertEqual(event.location, 'Test location test uuid')

=== modified file 'tests/autopilot/calendar_app/tests/test_new_event.py'
--- tests/autopilot/calendar_app/tests/test_new_event.py	2014-06-27 16:39:51 +0000
+++ tests/autopilot/calendar_app/tests/test_new_event.py	2014-07-23 18:17:21 +0000
@@ -34,6 +34,7 @@
 
     # TODO add tests for events in the future and in the past, all day event,
     # event with recurrence and event with reminders.
+    # also add tests for saving to different calendars
     # We currently can't change the date of the new event because of bug
     # http://pad.lv/1328600 on Autopilot.
     # --elopio - 2014-06-26
@@ -41,6 +42,7 @@
     def try_delete_event(self, event_name, filter_duplicates):
         try:
             day_view = self.main_view.go_to_day_view()
+            logger.debug('deleting event')
             day_view.delete_event(event_name, filter_duplicates)
         except Exception as exception:
             logger.warn(str(exception))
@@ -73,6 +75,7 @@
         event_details_page = day_view.open_event(test_event.name)
         self.assertEqual(
             test_event, event_details_page.get_event_information())
+        logger.debug('test over')
 
     def test_delete_event_must_remove_it_from_day_view(self):
         """Test deleting an event must no longer show it on the day view."""

